import React from "react";
import { useUuidGenerator } from "./useUuidGenerator";
import { UuidOutput } from "./UuidOutput";
import { UuidControls } from "./UuidControls";
import { UuidFooter } from "./UuidFooter";

// Helper: filter and format UUID as it streams

const MODERN_CARD_STYLE: React.CSSProperties = {
  maxWidth: 420,
  margin: "0 auto",
  marginTop: "8vh",
  padding: "2.5rem 2rem 2rem 2rem",
  background: "rgba(24, 24, 32, 0.85)",
  borderRadius: 24,
  boxShadow: "0 8px 32px 0 #0004, 0 1.5px 8px 0 #646cff22",
  display: "flex",
  flexDirection: "column",
  alignItems: "center",
  minHeight: 340,
  backdropFilter: "blur(8px)",
  border: "1.5px solid rgba(100,108,255,0.10)",
};
const MODERN_PROGRESS_STYLE: React.CSSProperties = {
  width: "100%",
  margin: "1.5rem 0 0.5rem 0",
  textAlign: "center",
  color: "#b3b3d1",
  fontSize: 17,
  fontWeight: 500,
};
const MODERN_ERROR_STYLE: React.CSSProperties = {
  color: "#ff4d6d",
  marginTop: 18,
  fontSize: 17,
  textAlign: "center",
  fontWeight: 500,
  letterSpacing: 0.2,
};

const EMOJI_HEADER = "🤖✨ UUIDv4 AI Generator ✨🔑";

const App: React.FC = () => {
  const {
    output,
    loading,
    progress,
    error,
    handleGenerate,
    handleAbort,
  } = useUuidGenerator();

  return (
    <div
      style={{
        minHeight: "100vh",
        minWidth: "100vw",
        width: "100vw",
        height: "100vh",
        background: "linear-gradient(120deg, #18181b 0%, #23234a 100%)",
        fontFamily:
          'Inter, JetBrains Mono, Fira Mono, Menlo, monospace, system-ui',
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        position: "fixed",
        top: 0,
        left: 0,
        zIndex: 0,
      }}
    >
      <div style={MODERN_CARD_STYLE}>
        <h1
          style={{
            margin: 0,
            fontWeight: 800,
            fontSize: 30,
            color: "#fff",
            letterSpacing: 1,
            textAlign: "center",
            marginBottom: 8,
            userSelect: "none",
            textShadow: "0 2px 8px #646cff22",
          }}
        >
          {EMOJI_HEADER}
        </h1>
        <UuidOutput output={output} />
        {progress && <div style={MODERN_PROGRESS_STYLE}>{progress}</div>}
        <UuidControls
          loading={loading}
          onGenerate={handleGenerate}
          onAbort={handleAbort}
        />
        {error && <div style={MODERN_ERROR_STYLE}>{error}</div>}
        <UuidFooter />
      </div>
    </div>
  );
};

export default App;
